@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2008-2011 Mike Massonnet <mmassonnet@xfce.org>
+ *  Copyright (c) 2008-2012 Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,6 +39,8 @@
 static void             panel_plugin_register           (XfcePanelPlugin *panel_plugin);
 XFCE_PANEL_PLUGIN_REGISTER (panel_plugin_register);
 
+static gboolean         plugin_set_size                 (MyPlugin *plugin,
+                                                         gint size);
 static gboolean         cb_button_pressed               (GtkButton *button,
                                                          GdkEventButton *event,
                                                          MyPlugin *plugin);
@@ -61,6 +63,7 @@ panel_plugin_register (XfcePanelPlugin *panel_plugin)
 {
   MyPlugin *plugin = plugin_register ();
   GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();
+  GtkWidget *mi = NULL;
 
   /* Menu Position Func */
   plugin->menu_position_func = (GtkMenuPositionFunc)my_plugin_position_menu;
@@ -70,7 +73,7 @@ panel_plugin_register (XfcePanelPlugin *panel_plugin)
   gtk_widget_set_tooltip_text (GTK_WIDGET (panel_plugin), _("Clipman"));
 
   /* Panel Button */
-  plugin->button = xfce_create_panel_toggle_button ();
+  plugin->button = xfce_panel_create_toggle_button ();
   if (gtk_icon_theme_has_icon (icon_theme, "clipman"))
     {
       plugin->image = xfce_panel_image_new_from_source ("clipman");
@@ -81,27 +84,52 @@ panel_plugin_register (XfcePanelPlugin *panel_plugin)
     }
   gtk_container_add (GTK_CONTAINER (plugin->button), plugin->image);
   gtk_container_add (GTK_CONTAINER (panel_plugin), plugin->button);
+
+#if LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+  xfce_panel_plugin_set_small (panel_plugin, TRUE);
+#endif
+
   xfce_panel_plugin_add_action_widget (panel_plugin, plugin->button);
   g_signal_connect (plugin->button, "button-press-event",
                     G_CALLBACK (cb_button_pressed), plugin);
 
-  /* Signals */
+  /* Context menu */
   xfce_panel_plugin_menu_show_about (panel_plugin);
+  xfce_panel_plugin_menu_show_configure (panel_plugin);
+  mi = gtk_check_menu_item_new_with_mnemonic (_("_Disable"));
+  xfce_panel_plugin_menu_insert_item (panel_plugin, GTK_MENU_ITEM (mi));
+  xfconf_g_property_bind (plugin->channel, "/tweaks/inhibit",
+                          G_TYPE_BOOLEAN, mi, "active");
+
+  /* Signals */
   g_signal_connect_swapped (panel_plugin, "about",
                             G_CALLBACK (plugin_about), plugin);
-  xfce_panel_plugin_menu_show_configure (panel_plugin);
   g_signal_connect_swapped (panel_plugin, "configure-plugin",
                             G_CALLBACK (plugin_configure), plugin);
   g_signal_connect_swapped (panel_plugin, "save",
                             G_CALLBACK (plugin_save), plugin);
   g_signal_connect_swapped (panel_plugin, "free-data",
                             G_CALLBACK (plugin_free), plugin);
+  g_signal_connect_swapped (panel_plugin, "size-changed",
+                            G_CALLBACK (plugin_set_size), plugin);
   g_signal_connect (plugin->menu, "deactivate",
                     G_CALLBACK (cb_menu_deactivate), plugin);
 
   gtk_widget_show_all (GTK_WIDGET (panel_plugin));
 }
 
+static gboolean
+plugin_set_size (MyPlugin *plugin,
+                 gint size)
+{
+#if LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+  size /= xfce_panel_plugin_get_nrows (plugin->panel_plugin);
+#endif
+  gtk_widget_set_size_request(GTK_WIDGET(plugin->button), size, size);
+
+  return TRUE;
+}
+
 static gboolean
 cb_button_pressed (GtkButton *button,
                    GdkEventButton *event,
@@ -130,14 +158,12 @@ my_plugin_position_menu (GtkMenu *menu,
                          gboolean *push_in,
                          MyPlugin *plugin)
 {
-  GtkWidget *button;
   gint button_width, button_height;
   GtkRequisition requisition;
   GtkOrientation orientation;
 
-  button = plugin->button;
   orientation = xfce_panel_plugin_get_orientation (plugin->panel_plugin);
-  gtk_widget_get_size_request (button, &button_width, &button_height);
+  gtk_widget_get_size_request (plugin->button, &button_width, &button_height);
   gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
   gdk_window_get_origin (gtk_widget_get_window (GTK_WIDGET (plugin->panel_plugin)), x, y);
 
