@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009-2011 Mike Massonnet <mmassonnet@xfce.org>
+ *  Copyright (c) 2009-2012 Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -113,12 +113,16 @@ plugin_register (void)
 
   /* ClipmanMenu */
   plugin->menu = clipman_menu_new ();
+#ifdef HAVE_QRENCODE
+  xfconf_g_property_bind (plugin->channel, "/settings/show-qr-code",
+                          G_TYPE_BOOLEAN, plugin->menu, "show-qr-code");
+#endif
   xfconf_g_property_bind (plugin->channel, "/tweaks/reverse-menu-order",
                           G_TYPE_BOOLEAN, plugin->menu, "reverse-order");
-  xfconf_g_property_bind (plugin->channel, "/tweaks/inhibit",
-                          G_TYPE_BOOLEAN, plugin->menu, "inhibit-menu-item");
   xfconf_g_property_bind (plugin->channel, "/tweaks/paste-on-activate",
                           G_TYPE_UINT, plugin->menu, "paste-on-activate");
+  xfconf_g_property_bind (plugin->channel, "/tweaks/never-confirm-history-clear",
+                          G_TYPE_BOOLEAN, plugin->menu, "never-confirm-history-clear");
 
   /* Load the data */
   plugin_load (plugin);
@@ -315,13 +319,13 @@ cb_about_dialog_url_hook (GtkAboutDialog *dialog,
 void
 plugin_about (MyPlugin *plugin)
 {
-  const gchar *artists[] = { "Mike Massonnet", NULL, };
-  const gchar *authors[] = { "(c) 2008-2011 Mike Massonnet",
+  const gchar *authors[] = { "(c) 2008-2012 Mike Massonnet",
                              "(c) 2005-2006 Nick Schermer",
                              "(c) 2003 Eduard Roccatello",
                              "",
                              _("Contributors:"),
                              "(c) 2008-2009 David Collins",
+			     "(c) 2013 Christian Hesse",
                              NULL, };
   const gchar *documenters[] = { "Mike Massonnet", NULL, };
   const gchar *license =
@@ -336,11 +340,10 @@ plugin_about (MyPlugin *plugin)
                          "logo-icon-name", "xfce4-clipman-plugin",
                          "comments", _("Clipboard Manager for Xfce"),
                          "version", PACKAGE_VERSION,
-                         "copyright", "Copyright © 2008-2011 Mike Massonnet",
+                         "copyright", "Copyright © 2003-2012 The Xfce development team",
                          "license", license,
                          "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-clipman-plugin",
                          "website-label", "goodies.xfce.org",
-                         "artists", artists,
                          "authors", authors,
                          "documenters", documenters,
                          "translator-credits", _("translator-credits"),
