@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009-2011 Mike Massonnet <mmassonnet@xfce.org>
+ *  Copyright (c) 2009-2012 Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include <libxfce4panel/libxfce4panel.h>
 #endif
 
-#include <daemon/daemon.h>
+#include <x11-clipboard-manager/daemon.h>
 #include "actions.h"
 #include "collector.h"
 #include "history.h"
